@@ -98,6 +98,7 @@ import org.osgi.framework.Bundle;
 import org.osgi.service.http.HttpContext;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
+import com.openexchange.java.StringAllocator;
 import com.openexchange.log.Log;
 import com.openexchange.log.LogFactory;
 
@@ -136,14 +137,11 @@ public class HttpServiceImpl implements HttpService {
      * {@inheritDoc}
      */
     @Override
-    public void registerServlet(
-            final String alias, final Servlet servlet, final Dictionary initparams, HttpContext httpContext)
-            throws ServletException, NamespaceException {
+    public void registerServlet(final String alias, final Servlet servlet, final Dictionary initparams, HttpContext httpContext) throws ServletException, NamespaceException {
 
-        LOG.info(
-                new StringBuilder(128).append("Registering servlet: ").append(servlet).append(", under: ").append(alias)
-                        .append(" with context: ").append(httpContext).toString());
-//                        .append(", with: ").append(initparams)
+        LOG.info(new StringAllocator(128).append("Registering servlet: ").append(servlet.getClass().getName()).append(", under: ").append(
+            alias).append(" with context: ").append(httpContext).toString());
+        // .append(", with: ").append(initparams)
 
         mainHttpHandler.registerServletHandler(alias, servlet, initparams, httpContext, this);
     }
@@ -152,12 +150,10 @@ public class HttpServiceImpl implements HttpService {
      * {@inheritDoc}
      */
     @Override
-    public void registerResources(final String alias, String prefix, HttpContext httpContext)
-            throws NamespaceException {
+    public void registerResources(final String alias, String prefix, HttpContext httpContext) throws NamespaceException {
 
-        LOG.info(
-                new StringBuilder(128).append("Registering resource: alias: ").append(alias).append(", prefix: ")
-                        .append(prefix).append(" and context: ").append(httpContext).toString());
+        LOG.info(new StringAllocator(128).append("Registering resource: alias: ").append(alias).append(", prefix: ").append(prefix).append(
+            " and context: ").append(httpContext).toString());
 
         mainHttpHandler.registerResourceHandler(alias, httpContext, prefix, this);
     }
@@ -167,7 +163,7 @@ public class HttpServiceImpl implements HttpService {
      */
     @Override
     public void unregister(final String alias) {
-        LOG.info(new StringBuilder(32).append("Unregistering alias: ").append(alias).toString());
+        LOG.info(new StringAllocator(32).append("Unregistering alias: ").append(alias).toString());
         mainHttpHandler.unregisterAlias(alias);
     }
 
