@@ -182,10 +182,12 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
     private static final class WatchInfo {
 
         final ScheduledTimerTask timerTask;
+        final Response handlerResponse;
 
-        WatchInfo(ScheduledTimerTask timerTask) {
+        WatchInfo(ScheduledTimerTask timerTask, Response handlerResponse) {
             super();
             this.timerTask = timerTask;
+            this.handlerResponse = handlerResponse;
         }
 
     }
@@ -210,11 +212,9 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
         // Ping stuff
         pingMap = new ConcurrentHashMap<FilterChainContext, WatchInfo>(512);
         {
-            final ConfigurationService service = Services.getService(ConfigurationService.class);
+            final ConfigurationService service = Services.optService(ConfigurationService.class);
             pingDelay = null == service ? 90000 : service.getIntProperty("com.openexchange.http.grizzly.pingDelay", 90000);
-
             maxPingCount = null == service ? 9 : service.getIntProperty("com.openexchange.http.grizzly.maxPingCount", 9);
-
             ping = null == service ? Ping.PROCESSING : Ping.pingFor(service.getProperty("com.openexchange.http.grizzly.ping", "PROCESSING").trim());
         }
         // Rest
@@ -314,7 +314,10 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
                         final WatchInfo watchInfo = pingMap.remove(ctx);
                         if (null != watchInfo) {
                             watchInfo.timerTask.cancel(false);
-                            Services.getService(TimerService.class).purge();
+                            final TimerService timerService = Services.optService(TimerService.class);
+                            if (null != timerService) {
+                                timerService.purge();
+                            }
                         }
                     }
                 }
@@ -359,7 +362,7 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
     private void initiatePing(final Response handlerResponse, final FilterChainContext ctx) {
         final Ping ping = this.ping;
         if (ping != Ping.NONE) {
-            final TimerService timerService = Services.getService(TimerService.class);
+            final TimerService timerService = Services.optService(TimerService.class);
             if (null != timerService) {
                 final ConcurrentMap<FilterChainContext, WatchInfo> cm = pingMap;
                 final Logger logger = LOGGER;
@@ -368,58 +371,73 @@ public class OXHttpServerFilter extends HttpServerFilter implements JmxMonitorin
                 final int maxPingCount = this.maxPingCount;
                 final AtomicInteger pingCount = new AtomicInteger(maxPingCount <= 0 ? Integer.MAX_VALUE : this.maxPingCount);
                 final AtomicReference<ScheduledTimerTask> ref = new AtomicReference<ScheduledTimerTask>();
+                final int pingDelay = this.pingDelay;
 
                 final Runnable r = new Runnable() {
 
                     @Override
                     public void run() {
-                        if (pingCount.decrementAndGet() < 0) {
-                            final ScheduledTimerTask timerTask = ref.get();
-                            if (null != timerTask) {
-                                timerTask.cancel(false);
-                            }
-                            return;
-                        }
                         try {
                             final WatchInfo watchInfo = cm.get(ctx);
-                            if (null != watchInfo) {
-                                final MemoryManager memoryManager = ctx.getMemoryManager();
-                                if (Ping.PROCESSING == ping) {
-                                    final Buffer encodedBuffer = memoryManager.allocate(128);
-                                    put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 102 Processing"));
-                                    put(memoryManager, encodedBuffer, crlfBytes);
-                                    put(memoryManager, encodedBuffer, crlfBytes);
-                                    encodedBuffer.trim();
-                                    encodedBuffer.allowBufferDispose(true);
-                                    ctx.write(encodedBuffer, true);
-                                } else if (Ping.CONTINUE == ping) {
-                                    final Buffer encodedBuffer = memoryManager.allocate(128);
-                                    put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 100 Continue"));
-                                    put(memoryManager, encodedBuffer, crlfBytes);
-                                    put(memoryManager, encodedBuffer, crlfBytes);
-                                    encodedBuffer.trim();
-                                    encodedBuffer.allowBufferDispose(true);
-                                    ctx.write(encodedBuffer, true);
-                                } else {
-                                    final Buffer buffer = memoryManager.allocate(128);
-                                    put(memoryManager, buffer, Charsets.toAsciiBytes(" "));
-                                    buffer.trim();
-                                    buffer.allowBufferDispose(true);
-                                    final OutputBuffer outputBuffer = handlerResponse.getOutputBuffer();
-                                    outputBuffer.writeBuffer(buffer);
-                                    outputBuffer.flush();
+                            boolean pingIssued = false;
+                            if (null != watchInfo && (watchInfo.handlerResponse instanceof OXResponse)) {
+                                final StampingNIOOutputStreamImpl stamped = (StampingNIOOutputStreamImpl) ((OXResponse) watchInfo.handlerResponse).createOutputStream();
+                                if (!stamped.closed) {
+                                    final long lastAccessed = stamped.lastAccessed;
+                                    if (lastAccessed > 0 && (System.currentTimeMillis() - lastAccessed) >= pingDelay) {
+                                        // Check whether to issue a ping
+                                        if (pingCount.decrementAndGet() < 0) {
+                                            // Not allowed to issue a further ping
+                                            final ScheduledTimerTask timerTask = ref.get();
+                                            if (null != timerTask) {
+                                                timerTask.cancel(false);
+                                            }
+                                            return;
+                                        }
+
+                                        // Issue a ping
+                                        final MemoryManager memoryManager = ctx.getMemoryManager();
+                                        if (Ping.PROCESSING == ping) {
+                                            final Buffer encodedBuffer = memoryManager.allocate(128);
+                                            put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 102 Processing"));
+                                            put(memoryManager, encodedBuffer, crlfBytes);
+                                            put(memoryManager, encodedBuffer, crlfBytes);
+                                            encodedBuffer.trim();
+                                            encodedBuffer.allowBufferDispose(true);
+                                            ctx.write(encodedBuffer, true);
+                                        } else if (Ping.CONTINUE == ping) {
+                                            final Buffer encodedBuffer = memoryManager.allocate(128);
+                                            put(memoryManager, encodedBuffer, Charsets.toAsciiBytes("HTTP/1.1 100 Continue"));
+                                            put(memoryManager, encodedBuffer, crlfBytes);
+                                            put(memoryManager, encodedBuffer, crlfBytes);
+                                            encodedBuffer.trim();
+                                            encodedBuffer.allowBufferDispose(true);
+                                            ctx.write(encodedBuffer, true);
+                                        } else {
+                                            final Buffer buffer = memoryManager.allocate(128);
+                                            put(memoryManager, buffer, Charsets.toAsciiBytes(" "));
+                                            buffer.trim();
+                                            buffer.allowBufferDispose(true);
+                                            final OutputBuffer outputBuffer = handlerResponse.getOutputBuffer();
+                                            outputBuffer.writeBuffer(buffer);
+                                            outputBuffer.flush();
+                                        }
+                                        pingIssued = true;
+                                    }
                                 }
                             }
+                            if (false == pingIssued) {
+                                pingCount.set(maxPingCount);
+                            }
                         } catch (final Exception e) {
                             logger.log(Level.WARNING, "Timer run failed: " + e.getMessage(), e);
                         }
                     }
                 };
 
-                final int delay = pingDelay;
-                final ScheduledTimerTask timerTask = timerService.scheduleWithFixedDelay(r, delay, delay);
+                final ScheduledTimerTask timerTask = timerService.scheduleWithFixedDelay(r, pingDelay, pingDelay);
                 ref.set(timerTask);
-                cm.put(ctx, new WatchInfo(timerTask));
+                cm.put(ctx, new WatchInfo(timerTask, handlerResponse));
             }
         }
     }
