@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright (c) 2010-2012 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010-2013 Oracle and/or its affiliates. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common Development
@@ -140,7 +140,7 @@ public class InputBuffer {
      * The default character encoding to use if none is specified by the
      * {@link org.glassfish.grizzly.http.HttpRequestPacket}.
      */
-    private String encoding = DEFAULT_HTTP_CHARACTER_ENCODING;
+    private String encoding = "UTF-8";
 
     /**
      * The {@link CharsetDecoder} used to convert binary to character data.
@@ -201,7 +201,7 @@ public class InputBuffer {
      * properly.
      * </p>
      *
-     * @param request the current request
+     * @param serverRequest the current request
      * @param ctx the FilterChainContext for the chain processing this request
      */
     public void initialize(final Request serverRequest,
@@ -271,7 +271,7 @@ public class InputBuffer {
         
         isWaitingDataAsynchronously = false;
 
-        encoding = DEFAULT_HTTP_CHARACTER_ENCODING;
+        encoding = "UTF-8";
 
     }
 
@@ -547,14 +547,20 @@ public class InputBuffer {
     /**
      * Fill the buffer (blocking) up to the requested length.
      * 
-     * @param length
+     * @param length how much content should attempt to buffer,
+     * <code>-1</code> means buffer entire request.
+     * 
      * @throws IOException
      */
     public void fillFully(final int length) throws IOException {
-        int remaining = length - inputContentBuffer.remaining();
+        if (length > 0) {
+            final int remaining = length - inputContentBuffer.remaining();
 
-        if (remaining > 0) {
-            fill(remaining);
+            if (remaining > 0) {
+                fill(remaining);
+            }
+        } else {
+            fill(-1);
         }
     }
 
@@ -721,7 +727,20 @@ public class InputBuffer {
         }
     }
 
-
+    public void replayPayload(final Buffer buffer) {
+        if (!isFinished()) {
+            throw new IllegalStateException("Can't replay when InputBuffer is not closed");
+        }
+        
+        closed = false;
+        readCount = 0;
+        
+        readAheadLimit = -1;
+        markPos = -1;
+        
+        inputContentBuffer = buffer;
+    }
+    
     /**
      * @return <code>true</code> if all request data has been read, otherwise
      *  returns <code>false</code>.
@@ -814,7 +833,7 @@ public class InputBuffer {
      * Appends the specified {@link Buffer} to the internal composite
      * {@link Buffer}.
      *
-     * @param buffer the {@link Buffer} to append
+     * @param httpContent the {@link Buffer} to append
      *
      * @return <code>true</code> if {@link ReadHandler}
      *  callback was invoked, otherwise returns <code>false</code>.
@@ -940,10 +959,11 @@ public class InputBuffer {
 
     /**
      * <p>
-     * Used to add additional http message chunk content to {@link #inputContentBuffer}.
+     * Used to add additional HTTP message chunk content to {@link #inputContentBuffer}.
      * </p>
      *
-     * @param requestedLen how much content should attempt to be read
+     * @param requestedLen how much content should attempt to be read,
+     * <code>-1</code> means read till the end of the message.
      *
      * @return the number of bytes actually read
      *
@@ -956,6 +976,7 @@ public class InputBuffer {
             final ReadResult rr = ctx.read();
             final HttpContent c = (HttpContent) rr.getMessage();
 
+            final boolean isLast = c.isLast();
             // Check if HttpContent is chunked message trailer w/ headers
             checkHttpTrailer(c);
             
@@ -964,6 +985,11 @@ public class InputBuffer {
             updateInputContentBuffer(b);
             rr.recycle();
             c.recycle();
+
+            if (isLast) {
+                finished();
+                break;
+            }
         }
 
         if (read > 0 || requestedLen == 0) {
